@@ -86,4 +86,15 @@ class ContactDatabaseManager(DatabaseManager):
         return contact
 
     def get_contacts_info(self):
+        self.get_data()
         return self.contact_collection.find({"identify_string": self.identify_string})
+
+    def get_groups_info(self):
+        self.get_data()
+        return self.category_collection.find({"identify_string": self.identify_string})
+
+    def get_contacts_info_in_group(self, category_id: int):
+        return self.contact_collection.find({
+            "identify_string": self.identify_string,
+            "category_id": category_id
+        })
